/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.ode.utils.sax;

import org.xml.sax.ErrorHandler;
import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;

public class FailOnErrorErrorHandler implements ErrorHandler {
  
  private ErrorHandler _child;
  
  public FailOnErrorErrorHandler() {
    this(new IgnoreAllErrorHandler());
  }
  
  public FailOnErrorErrorHandler(ErrorHandler eh) {
    _child = eh;
  }
  
  /**
   * @see ErrorHandler#error(org.xml.sax.SAXParseException)
   */  
  public void error(SAXParseException exception) throws SAXException {
    throw exception;
  }
  /**
   * @see ErrorHandler#fatalError(org.xml.sax.SAXParseException)
   */  
  public void fatalError(SAXParseException exception) throws SAXException {
    throw exception;
  }
  /**
   * @see ErrorHandler#warning(org.xml.sax.SAXParseException)
   */  
  public void warning(SAXParseException exception) throws SAXException {
    _child.warning(exception);
  }
}
